use core::cell::{RefCell, RefMut};

/// 只能在单核场景下保持安全的屑RefCell
pub struct SingleCell<T> {
    inner: RefCell<T>,
}

unsafe impl<T> Sync for SingleCell<T> {}

impl<T> SingleCell<T> {
    pub fn new(value: T) -> SingleCell<T> {
        SingleCell {
            inner: RefCell::new(value),
        }
    }

    /// 独占访问
    /// 当已被借用时访问会Panic
    pub fn exclusive_borrow(&self) -> RefMut<'_, T> {
        self.inner.borrow_mut()
    }
}
