use core::panic::PanicInfo;

use crate::log_error;
use crate::sbi::shutdown;

#[panic_handler]
fn panic(info: &PanicInfo) -> ! {
    if let Some(location) = info.location() {
        log_error!(
            "Panicked at {}:{} {}.",
            location.file(),
            location.line(),
            info.message()
        );
    } else {
        log_error!("Panicked: {}.", info.message());
    }

    shutdown(true)
}

pub fn clear_bss() {
    extern "C" {
        fn sbss();
        fn ebss();
    }

    for m in sbss as usize..ebss as usize {
        unsafe { (m as *mut u8).write_volatile(0) }
    }
}
